import traceback
import os
from lrabbit_scrapy.common_utils.print_log_helper import LogUtils
from pathlib import Path
import subprocess


def start_frida_server(servername):
    server_path = f'/data/local/tmp/{servername}'
    killserver = "adb shell su -c killall -9 " + servername
    os.system(killserver)
    subprocess.Popen(
        ["adb", "shell", "su", "-c", server_path])


def sslbypass(server_name='15.0.0'):
    try:
        start_frida_server(server_name)
    except Exception as e:
        traceback.print_exc()
        LogUtils.log_error("please check frida-server name or this  path is in /data/local/tmp?")
        exit(0)
    current_parent_path = Path(__file__).parent
    frida_path = os.path.join(current_parent_path, 'sslpass.js')
    frida_hook_cmd = f"frida -FU -l {frida_path} --no-pause"
    os.system(frida_hook_cmd)


if __name__ == '__main__':
    sslbypass()



from lrabbit_scrapy.spider import LrabbitSpider
from lrabbit_scrapy.common_utils.network_helper import RequestSession
from lrabbit_scrapy.common_utils.print_log_helper import LogUtils
from lrabbit_scrapy.common_utils.all_in_one import FileStore
import os
from lrabbit_scrapy.common_utils.mysql_helper import MysqlClient
from parsel import Selector


class Spider(LrabbitSpider):
    """
        spider_name : lrabbit blog spider
    """
    # unique spider name
    spider_name = "lrabbit_blog"
    # max thread worker numbers
    max_thread_num = 2
    # is open for every thread a mysql connection,if your max_thread_num overpass 10 and  in code need mysql query ,you need open this config
    thread_mysql_open = True
    # reset all task_list,every restart program will init task list
    reset_task_config = True
    # open loop init_task_list ,when your task is all fnish,and you want again ,you can open it
    loop_task_config = True
    # remove config option,if open it,then confirm option when you init task
    remove_confirm_config = True
    # config_path_name, this is env name ,is this code ,you need in linux to execute: export config_path="crawl.ini"
    config_env_name = "config_path"
    # redis db_num
    redis_db_config = 0
    # debug log ,open tracback log
    debug_config = False

    def __init__(self):
        super().__init__()
        self.session = RequestSession()
        self.proxy_session = RequestSession(proxies=None)
        csv_path = os.path.join(os.path.abspath(os.getcwd()), f"{self.spider_name}.csv")
        self.field_names = ['id', 'title', 'datetime']
        self.blog_file = FileStore(file_path=csv_path, filed_name=self.field_names)

    def worker(self, *args):
        task = args[0]
        mysql_client: MysqlClient
        if len(args) == 2:
            mysql_client = args[1]
            mysql_client.execute("select id from rookie limit 100")
            # mysql_client.execute("")
        url = f'http://www.lrabbit.life/post_detail/?id={task}'
        LogUtils.log_running(url)
        res = self.session.send_request(method='GET', url=url)
        selector = Selector(res.text)
        title = selector.css(".detail-title h1::text").get()
        datetime = selector.css(".detail-info span::text").get()
        if title:
            post_data = {"id": task, "title": title, 'datetime': datetime}
            self.blog_file.write(post_data)
            # when you succes get content update redis stat
            self.update_stat_redis()
        LogUtils.log_finish(task)

    def init_task_list(self):

        # you can get init task from mysql
        res = self.mysql_client.query("select id from rookie limit 100 ")
        return [task['id'] for task in res]
        # return [i for i in range(100)]


if __name__ == '__main__':
    spider = Spider()
    spider.run()
